@@ -14,6 +14,8 @@
 
 #include <bsoncxx/array/element.hpp>
 
+#include <cstdlib>
+#include <cstring>
 #include <stdexcept>
 
 #include <bsoncxx/config/private/prelude.hh>
