@@ -14,9 +14,11 @@
 
 #include <mongocxx/hint.hpp>
 
+#include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/builder/basic/sub_document.hpp>
 #include <bsoncxx/builder/concatenate.hpp>
+#include <bsoncxx/stdx/make_unique.hpp>
 
 #include <mongocxx/config/private/prelude.hh>
 
