@@ -1127,7 +1127,7 @@ TEST_CASE("Custom endpoint", "[client_side_encryption]") {
     //   key: "arn:aws:kms:us-east-1:579766882180:key/89fcc2c4-08b0-4bd9-9f25-e30687b580d0",
     //   endpoint: "kms.us-east-2.amazonaws.com"
     // }
-    // Expect this to fail with an exception with a message containing the string: "us-east-1"
+    // Expect this to fail with an exception.
     auto endpoint_error_masterkey =
         document{} << "region"
                    << "us-east-1"
@@ -1135,7 +1135,7 @@ TEST_CASE("Custom endpoint", "[client_side_encryption]") {
                    << "arn:aws:kms:us-east-1:579766882180:key/89fcc2c4-08b0-4bd9-9f25-e30687b580d0"
                    << "endpoint"
                    << "kms.us-east-2.amazonaws.com" << finalize;
-    _run_endpoint_test(&client_encryption, endpoint_error_masterkey.view(), {{"us-east-1"}});
+    _run_endpoint_test(&client_encryption, endpoint_error_masterkey.view(), {{""}});
 
     // Call client_encryption.createDataKey() with "aws" as the provider and the following
     // masterKey:
